# HSTGRISM

Webpage: https://bkornpob.github.io/hstgrism/

## 8.3.0
make_contamination_mask is introduced. (Note: This is redundant to ObjectMask class).

## 8.2.0
WFC3IRG141 is introduced.

## 8.1.0
ObjectMask is introduced.